"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Tree.py,v 1.1.2.1 2003/03/11 19:37:11 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
from Controls import Control
import Parameters as wx


class TreeCtrl(Control):
    """"""

    def AddRoot(self):
        """"""
        pass

    def AppendItem(self):
        """"""
        pass

    def AssignImageList(self):
        """"""
        pass

    def AssignStateImageList(self):
        """"""
        pass

    def Collapse(self):
        """"""
        pass

    def CollapseAndReset(self):
        """"""
        pass

    def Create(self):
        """"""
        pass

    def Delete(self):
        """"""
        pass

    def DeleteAllItems(self):
        """"""
        pass

    def DeleteChildren(self):
        """"""
        pass

    def EditLabel(self):
        """"""
        pass

    def EnsureVisible(self):
        """"""
        pass

    def Expand(self):
        """"""
        pass

    def GetBoundingRect(self):
        """"""
        pass

    def GetChildrenCount(self):
        """"""
        pass

    def GetCount(self):
        """"""
        pass

    def GetEditControl(self):
        """"""
        pass

    def GetFirstChild(self):
        """"""
        pass

    def GetFirstVisibleItem(self):
        """"""
        pass

    def GetImageList(self):
        """"""
        pass

    def GetIndent(self):
        """"""
        pass

    def GetItemBackgroundColour(self):
        """"""
        pass

    def GetItemData(self):
        """"""
        pass

    def GetItemFont(self):
        """"""
        pass

    def GetItemImage(self):
        """"""
        pass

    def GetItemParent(self):
        """"""
        pass

    def GetItemSelectedImage(self):
        """"""
        pass

    def GetItemText(self):
        """"""
        pass

    def GetItemTextColour(self):
        """"""
        pass

    def GetLastChild(self):
        """"""
        pass

    def GetNextChild(self):
        """"""
        pass

    def GetNextSibling(self):
        """"""
        pass

    def GetNextVisible(self):
        """"""
        pass

    def GetPrevSibling(self):
        """"""
        pass

    def GetPrevVisible(self):
        """"""
        pass

    def GetPyData(self):
        """"""
        pass

    def GetRootItem(self):
        """"""
        pass

    def GetSelection(self):
        """"""
        pass

    def GetSelections(self):
        """"""
        pass

    def GetSpacing(self):
        """"""
        pass

    def GetStateImageList(self):
        """"""
        pass

    def HitTest(self):
        """"""
        pass

    def InsertItem(self):
        """"""
        pass

    def InsertItemBefore(self):
        """"""
        pass

    def IsBold(self):
        """"""
        pass

    def IsExpanded(self):
        """"""
        pass

    def IsSelected(self):
        """"""
        pass

    def IsVisible(self):
        """"""
        pass

    def ItemHasChildren(self):
        """"""
        pass

    def PrependItem(self):
        """"""
        pass

    def ScrollTo(self):
        """"""
        pass

    def SelectItem(self):
        """"""
        pass

    def SetImageList(self):
        """"""
        pass

    def SetIndent(self):
        """"""
        pass

    def SetItemBackgroundColour(self):
        """"""
        pass

    def SetItemBold(self):
        """"""
        pass

    def SetItemData(self):
        """"""
        pass

    def SetItemFont(self):
        """"""
        pass

    def SetItemHasChildren(self):
        """"""
        pass

    def SetItemImage(self):
        """"""
        pass

    def SetItemSelectedImage(self):
        """"""
        pass

    def SetItemText(self):
        """"""
        pass

    def SetItemTextColour(self):
        """"""
        pass

    def SetPyData(self):
        """"""
        pass

    def SetSpacing(self):
        """"""
        pass

    def SetStateImageList(self):
        """"""
        pass

    def SortChildren(self):
        """"""
        pass

    def Toggle(self):
        """"""
        pass

    def Unselect(self):
        """"""
        pass

    def UnselectAll(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class TreeItemAttr:
    """"""

    def GetBackgroundColour(self):
        """"""
        pass

    def GetFont(self):
        """"""
        pass

    def GetTextColour(self):
        """"""
        pass

    def HasBackgroundColour(self):
        """"""
        pass

    def HasFont(self):
        """"""
        pass

    def HasTextColour(self):
        """"""
        pass

    def SetBackgroundColour(self):
        """"""
        pass

    def SetFont(self):
        """"""
        pass

    def SetTextColour(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class TreeItemData(Object):
    """"""

    def GetData(self):
        """"""
        pass

    def GetId(self):
        """"""
        pass

    def SetData(self):
        """"""
        pass

    def SetId(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class TreeItemId:
    """"""

    def IsOk(self):
        """"""
        pass

    def Ok(self):
        """"""
        pass

    def __cmp__(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

